.. Omero Slurm Client documentation master file, created by
   sphinx-quickstart on Mon May 15 15:58:31 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to BIOMERO's documentation!
==============================================


.. Get started

***********************

.. toctree::
   :caption: BIOMERO - Get Started
   :maxdepth: 4

   readme_link

.. Tutorials

***********************

.. toctree::
   :caption: Tutorials
   :maxdepth: 2

   tutorial_link


.. Package

***********************

.. toctree::
   :caption: Package
   :maxdepth: 5

   modules

Indices and tables
==================

* :ref:`genindex`
